# Model results and output gdx files for MESSAGEix

This is the default folder for the output gdx files
generated by GAMS when solving a MESSAGEix model instance.

**Please do not commit gdx files to the GitHub repository!**

The gdx files have to be imported to the corresponding
MESSAGE-scheme ixmp.Scenario instance via the Python or R interface 
of the ix modeling platform [(ixmp)](https://github.com/iiasa/ixmp).
